Documentation
¶
Overview ¶
Package libraryofcongress provides methods for working with Library of Congress (LoC) metadata files in an SFO Museum context.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterLookup ¶
func RegisterLookup(ctx context.Context, scheme string, init_func LookupInitializationFunc) error
RegisterLookup() associates 'scheme' with 'init_func' in an internal list of avilable `Lookup` implementations.
Types ¶
type Lookup ¶
type Lookup interface {
// Find() searches for a given LoC identifier.
Find(context.Context, string) ([]interface{}, error)
// Append() indexes a LoC record with one or more identifiers.
Append(context.Context, interface{}) error
}
type Lookup provides an interface for indexing and search Library of Congress (LoC) identifiers.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package cmd provides command line tools for working with Library of Congress (LoC) data.
|
Package cmd provides command line tools for working with Library of Congress (LoC) data. |
|
lookup
command
|
|
|
to-sqlite
command
|
|
|
Package data provides embedded Library of Congress (LoC) data files.
|
Package data provides embedded Library of Congress (LoC) data files. |
|
Package lcnaf provides methods for working with Library of Congress Named Authority File (LCNAF) data.
|
Package lcnaf provides methods for working with Library of Congress Named Authority File (LCNAF) data. |
|
Package lcsh provides methods for working with Library of Congress Subject Heading (LCSH) data.
|
Package lcsh provides methods for working with Library of Congress Subject Heading (LCSH) data. |
|
Package sqlite provides methods for working with Library of Congress (LoC) data in an SFO Museum context.
|
Package sqlite provides methods for working with Library of Congress (LoC) data in an SFO Museum context. |
Click to show internal directories.
Click to hide internal directories.